"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bootstrapTestInstance = exports.user2Wallet = exports.userWallet = exports.registryDeployer = void 0;
const issuer_1 = require("@energyweb/issuer");
const issuer_api_1 = require("@energyweb/issuer-api");
const typeorm_1 = require("@nestjs/typeorm");
const common_1 = require("@nestjs/common");
const bull_1 = require("@nestjs/bull");
const utils_general_1 = require("@energyweb/utils-general");
const testing_1 = require("@nestjs/testing");
const origin_backend_utils_1 = require("@energyweb/origin-backend-utils");
const src_1 = require("../src");
const issuer_api_2 = require("@energyweb/issuer-api");
const passport_1 = require("@nestjs/passport");
const testLogger = new common_1.Logger('e2e');
const web3 = 'http://localhost:8545';
const provider = utils_general_1.getProviderWithFallback(web3);
exports.registryDeployer = {
    address: '0xBBad6d3d893e9E75fE8e73cb5Ac6E2C82C9A91d0',
    privateKey: '0xb9e54b01a556f150e05272c25a9362096bce3b86e81e481c4d263e7768ac8c74'
};
exports.userWallet = {
    address: '0xeF99b2A55E6D070bA2D12f79b368148BF7d6Fc10',
    privateKey: '0xb4caabdf3fc44a7ca34238d3c7363127d5dbfdfd39244ebe2dad2e472e7eda60'
};
exports.user2Wallet = {
    address: '0x212fb883109dC887a605B09078E219Db75e5AAc7',
    privateKey: '0x9d4b1fbf6a730b6399ada447b0cf19a25ed91f819d7c860d0aa0de779badc8c2'
};
const deployRegistry = async () => {
    return issuer_1.Contracts.migrateRegistry(provider, exports.registryDeployer.privateKey);
};
const deployIssuer = async (registry) => {
    return issuer_1.Contracts.migrateIssuer(provider, exports.registryDeployer.privateKey, registry);
};
const bootstrapTestInstance = async () => {
    const registry = await deployRegistry();
    const issuer = await deployIssuer(registry.address);
    const QueueingModule = () => {
        return bull_1.BullModule.forRoot({
            redis: process.env.REDIS_URL ?? { host: 'localhost', port: 6379 }
        });
    };
    const moduleFixture = await testing_1.Test.createTestingModule({
        imports: [
            typeorm_1.TypeOrmModule.forRoot({
                type: 'postgres',
                host: process.env.DB_HOST ?? 'localhost',
                port: Number(process.env.DB_PORT) ?? 5432,
                username: process.env.DB_USERNAME ?? 'postgres',
                password: process.env.DB_PASSWORD ?? 'postgres',
                database: process.env.DB_DATABASE ?? 'origin',
                entities: issuer_api_2.entities,
                logging: ['info'],
                keepConnectionAlive: true
            }),
            src_1.CertificateModule,
            QueueingModule(),
            issuer_api_1.BlockchainPropertiesModule,
            passport_1.PassportModule.register({ defaultStrategy: 'jwt' })
        ],
        providers: [origin_backend_utils_1.DatabaseService]
    }).compile();
    const app = moduleFixture.createNestApplication();
    const certificateService = await app.resolve(src_1.CertificateService);
    const databaseService = await app.resolve(origin_backend_utils_1.DatabaseService);
    const blockchainPropertiesService = await app.resolve(issuer_api_1.BlockchainPropertiesService);
    const blockchainProperties = await blockchainPropertiesService.create(provider.network.chainId, registry.address, issuer.address, web3, exports.registryDeployer.privateKey);
    await issuer_1.CertificateUtils.approveOperator(exports.registryDeployer.address, blockchainProperties.wrap(exports.userWallet.privateKey));
    await issuer_1.CertificateUtils.approveOperator(exports.registryDeployer.address, blockchainProperties.wrap(exports.user2Wallet.privateKey));
    app.useLogger(testLogger);
    app.enableCors();
    return {
        databaseService,
        certificateService,
        app
    };
};
exports.bootstrapTestInstance = bootstrapTestInstance;
//# sourceMappingURL=setup.js.map